_io.textio: fix character type, use Py_UCS4 instead of Py_UNICODE
diff --git a/Modules/_io/textio.c b/Modules/_io/textio.c
index 9c06ec8..880a5f0 100644
--- a/Modules/_io/textio.c
+++ b/Modules/_io/textio.c
@@ -347,7 +347,7 @@
                 memchr(in_str, '\n', PyUnicode_KIND_SIZE(kind, len)) != NULL) {
                 Py_ssize_t i = 0;
                 for (;;) {
-                    Py_UNICODE c;
+                    Py_UCS4 c;
                     /* Fast loop for non-control characters */
                     while (PyUnicode_READ(kind, in_str, i) > '\n')
                         i++;
@@ -1570,7 +1570,7 @@
 }
 
 
 /* NOTE: `end` must point to the real end of the Py_UNICODE storage,
    that is to the NUL character. Otherwise the function will produce
    incorrect results. */
 static char *
@@ -1614,7 +1614,7 @@
         for (;;) {
             Py_UCS4 ch;
             /* Fast path for non-control chars. The loop always ends
-               since the Py_UNICODE storage is NUL-terminated. */
+               since the Unicode string is NUL-terminated. */
             while (PyUnicode_READ(kind, s, 0) > '\r')
                 s += size;
             if (s >= end) {
@@ -1570,7 +1570,7 @@
 
 
-/* NOTE: `end` must point to the real end of the Py_UNICODE storage,
+/* NOTE: `end` must point to the real end of the Py_UCS4 storage,
    that is to the NUL character. Otherwise the function will produce
    incorrect results. */